| Coxph | R Documentation |
Cox model with fully parameterised baseline hazard function
Coxph(formula, data, subset, weights, offset, cluster, na.action = na.omit,
...)
formula |
an object of class |
data |
an optional data frame, list or environment (or object
coercible by |
subset |
an optional vector specifying a subset of observations to be used in the fitting process. |
weights |
an optional vector of weights to be used in the fitting
process. Should be |
offset |
this can be used to specify an _a priori_ known component to
be included in the linear predictor during fitting. This
should be |
cluster |
optional factor with a cluster ID employed for computing clustered covariances. |
na.action |
a function which indicates what should happen when the data
contain |
... |
additional arguments to |
The original implementation of Cox models via the partial likelihood,
treating the baseline hazard function as a nuisance parameter, is available
in coxph. This function allows simultaneous
estimation of the log-hazard ratios and the log-cumulative baseline hazard,
the latter parameterised by a Bernstein polynomial. The model can be fitted
under stratification (time-varying coefficients), all types of random
censoring and trunction. An early reference to this parameterisation is
\bibcitettram::McLain:Ghosh:2013.
The response is bounded (bounds = c(0, Inf)) when specified as a
Surv object. Otherwise, bounds can be specified via
....
Parameters are log-hazard ratios comparing treatment (or a one unit increase in a numeric variable) with a reference.
Details about the model parameterisation, estimation and implementation can be found in \bibcitettram::Hothorn:Moest:Buehlmann:2017, \bibcitettram::Siegfried:Tamasi:Hothorn:2026, and \bibcitettram::Hothorn:2018.
An object of class Coxph, with corresponding coef,
vcov, logLik, estfun, summary,
print, plot and predict methods.
*
data("GBSG2", package = "TH.data")
library("survival")
(m1 <- coxph(Surv(time, cens) ~ horTh, data = GBSG2))
(m2 <- Coxph(Surv(time, cens) ~ horTh, data = GBSG2))
### McLain & Ghosh (2013)
(m3 <- Coxph(Surv(time, cens) ~ horTh, data = GBSG2,
frailty = "Gamma"))
### Wald intervals
confint(m1)
confint(m2)
### profile likelihood interval
confint(profile(m2))
### see ?score_test for score intervals
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.