An object of class Survreg, with corresponding coef,
vcov, logLik, estfun, summary,
print, plot and predict methods.
Details
Parametric survival models reusing the interface of
survreg. The parameterisation is, however, a little
different, see the package vignette.
The model is defined with a negative shift term. Large values of the
linear predictor correspond to large values of the conditional
expectation response (but this relationship is nonlinear).
Parameters are log-hazard ratios comparing a reference with
treatment (or a one unit increase in a numeric variable).
Details about the model parameterisation, estimation and implementation
can be found in tram::Hothorn:Moest:Buehlmann:2017,
tram::Siegfried:Tamasi:Hothorn:2026, and
tram::Hothorn:2018.